==> node-babel7_7.9.6%2B~cs66.71.39.orig.tar.gz: babel-7.9.6/.github/ISSUE_TEMPLATE/Bug_report.md <==
---
name: "\U0001F41B Bug Report"
about: "If something isn't working as expected \U0001F914."
title: ''
labels: 'i: bug, i: needs triage'
assignees: ''

---

## Bug Report

<!-- Check this if you would like to implement a PR, we are more than happy to help you go through the process !-->
- [ ] I would like to work on a fix!

<!--
@babel/eslint-parser:
  If you are having issues with JSX you might want to check out eslint-plugin-react. If there's an issue with new experimental syntax you might need check if it's supported by @babel/eslint-plugin.
-->

**Current Behavior**
A clear and concise description of the behavior.

**Input Code**
- REPL or Repo link if applicable:

```js
var your => (code) => here;
```

**Expected behavior/code**
A clear and concise description of what you expected to happen (or code).

**Babel Configuration (babel.config.js, .babelrc, package.json#babel, cli command, .eslintrc)**
- Filename: `babel.config.js`

```js
{
  "your": { "config": "here" }
}
```

**Environment**
<!--- Tip: Instead of filling out the questions below, you can run `npx envinfo --preset babel` and paste the result below ``` -->
```

```
- Babel version(s): [e.g. v6.0.0, v7.0.0-beta.34]
- Node/npm version: [e.g. Node 8/npm 5]
- OS: [e.g. OSX 10.13.4, Windows 10]
- Monorepo: [e.g. yes/no/Lerna]
- How you are using Babel: [e.g. `cli`, `register`, `loader`]

**Possible Solution**
<!--- If you have suggestions on a fix for the bug -->

**Additional context/Screenshots**
Add any other context about the problem here. If applicable, add screenshots to help explain.

==> node-babel7_7.11.0%2B~cs65.71.38.orig.tar.gz: babel-7.11.0/.github/ISSUE_TEMPLATE/Bug_report.md <==
---
name: "\U0001F41B Bug Report"
about: "If something isn't working as expected \U0001F914."
title: ''
labels: 'i: bug, i: needs triage'
assignees: ''

---

## Bug Report

<!-- If you would like to implement a PR, we are more than happy to help you go through the process!-->
- [ ] I would like to work on a fix!

<!--
@babel/eslint-parser:
  If you are having issues with JSX you might want to check out eslint-plugin-react. If there's an issue with new experimental syntax you might need check if it's supported by @babel/eslint-plugin.
-->

**Current behavior**
A clear and concise description of the behavior.

- [REPL](babeljs.io/repl), [Codesandbox](https://codesandbox.io/s/babel-repl-custom-plugin-7s08o?file=/src/index.js), or GitHub Repo helps!

**Input Code**

```js
var your => (code) => here;
```

**Expected behavior**
A clear and concise description of what you expected to happen (or code).

**Babel Configuration (babel.config.js, .babelrc, package.json#babel, cli command, .eslintrc)**
- Filename: `babel.config.js`

```js
{
  "your": { "config": "here" }
}
```

**Environment**
<!--- Tip: Instead of filling out the questions below, you can run `npx envinfo --preset babel` and paste the result below ``` -->
```

```
- Babel version(s): [e.g. v6.0.0, v7.0.0-beta.34]
- Node/npm version: [e.g. Node 8/npm 5]
- OS: [e.g. OSX 10.13.4, Windows 10]
- Monorepo: [e.g. yes/no/Lerna]
- How you are using Babel: [e.g. `cli`, `register`, `loader`]

**Possible Solution**
<!--- If you have suggestions on a fix for the bug -->

**Additional context**
Add any other context about the problem here. Or a screenshot if applicable
